@@ -247,8 +247,8 @@ class IndexedArray(awkward.array.base.AwkwardArrayWithContent):
         self._valid()
         return self._util_flatten(self._content[self._index], axis)
 
-    def pad(self, length, maskedwhen=True, clip=False):
-        return self._util_pad(self._content[self._index], length, maskedwhen, clip)
+    def pad(self, length, maskedwhen=True, clip=False, axis=0):
+        return self._util_pad(self._content[self._index], length, maskedwhen, clip, axis)
 
     def regular(self):
         self._valid()
@@ -725,8 +725,8 @@ class SparseArray(awkward.array.base.AwkwardArrayWithContent):
             out[mask] = content[self._inverse[mask]]
         return out
 
-    def pad(self, length, maskedwhen=True, clip=False):
-        return self._util_pad(self._content.dense, length, maskedwhen, clip)
+    def pad(self, length, maskedwhen=True, clip=False, axis=0):
+        return self._util_pad(self._content.dense, length, maskedwhen, clip, axis)
 
     def regular(self):
         self._valid()
